<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja_JP" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Webブラウザなしでも大丈夫!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>バージョン %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>ライセンス: 1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1はフリーソフトウェアですが、開発には貴重な時間が費やされています。</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>継続的な開発を&lt;a href=&apos;%1&apos;&gt;支援する&lt;/a&gt;には%2に寄付してください。</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>%2を使って、%1をあなたの言語に翻訳してください</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>%1 によって作られました</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation>オープンソース・ソフトウェア</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>アイコンは%1さんのデザインです。</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;で配布されます</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Minitubeについて</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>ライセンスコードを入力してください</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>メール(&amp;E):</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>コード(&amp;C):</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>%1のライセンスを取得してください</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>試用版の期限が切れました。</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>製品版では、快適に動画を視聴することができます。</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>現在は、ライセンスがないため、このアプリケーションは%1日に期限切れとなります。</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>あなたが製品版を購入することによって、%1の開発を支援することができます。</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>試用版を使用</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>ライセンスを入力</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>ライセンスを購入</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>ダウンロード</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>%1による</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation><numerusform>%n 個の新しい動画があります</numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>すべてのチャンネル</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>未視聴の動画</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>名前順</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>更新日が新しい順</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>購読日が新しい順</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>視聴日が新しい順</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>視聴回数が多い順</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>並び替え</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>視聴済みの動画をマーク</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>動画の更新を確認</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>購読済みのものがありません。チャンネルを購読するには星マークをクリックします。</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>全ての動画</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>未視聴の動画</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>見たものをマーク</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>購読を解除</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>購読したチャンネルに更新はありません。</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>たった今</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation><numerusform>%n 時間前</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation><numerusform>%n 日前</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation><numerusform>%n か月前</numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation>キロ</translation>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation>メガ</translation>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation>バイト</translation>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1回 閲覧</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation><numerusform>%n 週間前</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/秒</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/秒</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/秒</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>分</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>残り %4 %5</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1を%2にダウンロード中</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>ダウンロード完了</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation><numerusform>%n 個のダウンロード</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>場所を変更...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>ダウンロード場所を選択</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>ダウンロード場所を変更しました。</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>現在ダウンロードしているファイルは移動されます。</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>%1にダウンロード中</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>ダウンロード</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>実行ファイルがウイルスによって置き換えられた可能性があります。</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1は実行されません。再インストールしてください。</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>終了</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>再インストール</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>再生</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>再生/一時停止</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>現在の曲が終わったら停止</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>次の曲</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>前の曲</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>音量を上げる</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>音量を下げる</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>ミュート</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>後方へ</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>前方へ</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>キーワードで動画とチャンネルを検索します</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>カテゴリ</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>カテゴリ別に動画を参照します</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>購読</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>購読したチャンネルを視聴します</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>さあリラックスしましょう</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>ウィンドウ(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>最小化(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>再生停止(&amp;S)</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>再生を停止し、検索画面に戻ります</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>前へ(&amp;R)</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>前の動画へ戻ります</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>次へ(&amp;k)</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>次の動画へ進みます</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>再生(&amp;P)</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>再生を再開します</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>フルスクリーンモード(&amp;F)</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>フルスクリーンモードで再生します</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>コンパクトモード(&amp;C)</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>プレイリストとツールバーを隠します</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>YouTubeのページを開く(&amp;Y)</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>一時停止してYouTubeのページを開きます</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>YouTubeへのリンクをコピー(&amp;L)</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>この動画のYouTubeページへのリンクをコピーします</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>動画のURLをコピー(&amp;U)</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>現在の動画のURLをコピーします</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>他のパートを探す(&amp;P)</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>この動画の他のパートを検索します</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>削除(&amp;R)</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>プレイリストから選択した動画を削除します</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>上へ(&amp;U)</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>選択した動画をプレイリスト内で上へ移動させます</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>下へ(&amp;D)</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>選択した動画をプレイリスト内で下へ移動させます</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>検索履歴を消去(&amp;C)</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>検索履歴を消去します。取り消しは出来ません。</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>終了(&amp;Q)</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Minitubeを終了します</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>ウェブサイト(&amp;W)</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1のウェブサイトを開きます</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>寄付する(&amp;D)</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>寄付して%1の開発を助けます</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Minitubeについて(&amp;A)</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>%1について</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>動画を検索します</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>ミュートにします</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>手動で再生(&amp;M)</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>動画の自動再生をしない</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>ダウンロード(&amp;D)</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>動画のダウンロードについての詳細を表示</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>ダウンロード(&amp;D)</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>現在の動画をダウンロード</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>スナップショットを撮る(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>チャンネル購読(&amp;S)</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>現在の動画を%1で共有します</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>メール(&amp;E)</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>メール</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>最前面に表示(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>再生終了後に停止(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>問題点を報告する(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>絞り込み検索(&amp;R)</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>その他...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>関連動画(&amp;R)</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>関連動画を検索します</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>ブラウザで見る(&amp;B)</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>制限付きモード</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>不適切なコンテンツを含む可能性のある動画を非表示にする</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>メニューバーを切り替え(&amp;M)</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>メニュー</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>%1を評価(&amp;L)</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>%1を購入する</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>アプリケーション(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>再生(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>プレイリスト(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>動画(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>共有(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>音量を上げるには%1を、下げるには%2を押します</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>コンテンツの地域を選択</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1を開いています</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>進行中の%1のダウンロードを停止しますか？</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>あなたは今%1を停止した場合は、このダウンロードはキャンセルされます。</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>閉じてダウンロードをキャンセル</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>ダウンロードが完了するまでお待ちください</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>エラー: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>一時停止(&amp;P)</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>再生を一時停止します</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;読込中...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>フルスクリーンモードを終了する(&amp;F)</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>残り時間: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>ボリューム%1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>ミュートにしました</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>ミュートを解除しました</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>最大画質を%1に設定する</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>プライバシーは保護されています</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>ダウンロード完了</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 バージョン %2 が利用可能です。</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>あとで通知する</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>ALTキーを押すことでメニューバーにアクセスできます</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>YouTube のリンクを別のアプリケーションに貼り付けることができます</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>他のアプリケーションに動画のURLを貼り付けることができます</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>リンクは制限時間内のみ有効です。</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>%1をダウンロード中</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>から</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>パート</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>エピソード</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>%1に送る</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>%1の購読を解除する</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>%1を購読する</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation>%1 に切り替えました</translation>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>%1の購読を解除しました</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>%1を購読しました</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>新しいバージョンの%1があります！</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2があります。あなたは%3です。</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>今すぐダウンロードしますか？</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>このバージョンをスキップ</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>後で通知</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>アップデートする</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>貼り付け</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation>動画を拾う</translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1は%2(%3)%4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>準備中</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>失敗</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>完了</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>ダウンロードを停止</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>%1を表示</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>親フォルダーを開く</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>ダウンロード再開</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>さらに%1件表示</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>見つかりませんでした</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>見つかりませんでした</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>並び順</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>関連性</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日付</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>閲覧回数</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>評価</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>すべて</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>今日</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>一週間以内</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>１ヶ月以内</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>再生時間</translation>
    </message>
    <message>
        <source>All</source>
        <translation>すべて</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>短い</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>普通</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>長い</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>4分以下</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>4～20分</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>20分超</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>画質</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>高画質</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720pまたは最高画質</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>完了</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>完了</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>ようこそ&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;へ</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>を検索する。</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>動画</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>キーワードを入力して</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>最近検索したキーワード</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>最近のチャンネル</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>製品版を入手する</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>戻る(&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>進む(&amp;F)</translation>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>%1 に進む</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>%1 に戻る</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>絞り込み検索</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>もしかして: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>場所を変更...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>%1にスナップショットを保存しました</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>スナップショットの場所を変更しました。</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>とても人気</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>アップデートをダウンロード中...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>%1 をダウンロードしています...</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>アルジェリア</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>アルゼンチン</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>オーストラリア</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>ベルギー</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>ブラジル</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>カナダ</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>チリ</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>コロンビア</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>チェコ共和国</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>エジプト</translation>
    </message>
    <message>
        <source>France</source>
        <translation>フランス</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>ドイツ</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>ガーナ</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>ギリシャ</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>香港</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>ハンガリー</translation>
    </message>
    <message>
        <source>India</source>
        <translation>インド</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>インドネシア</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>アイルランド</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>イスラエル</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>イタリア</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>日本</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>ヨルダン</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>ケニア</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>マレーシア</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>メキシコ</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>モロッコ</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>オランダ</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>ニュージーランド</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>ナイジェリア</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>ペルー</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>フィリピン</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>ポーランド</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>ロシア</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>サウジアラビア</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>シンガポール</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>南アフリカ</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>韓国</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>スペイン</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>スウェーデン</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>台湾</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>チュニジア</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>トルコ</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>ウガンダ</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>アラブ首長国連邦</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>イギリス</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>イエメン</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>全世界</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>%1の動画を取得できませんでした</translation>
    </message>
</context>
</TS>